# prana

 Loosely translated Sanskrit word for 'Energy'. Just another interview challenge.


## Development

1. Clone: `git clone git@github.com:dhilipsiva/prana.git`
1. Goto folder: `cd prana`
1. Create a new Python 3 virtialenv `pipenv --three`
1. To get into shell: `pipenv shell`
